@@ -1,6 +1,6 @@
 ************************************************************************
 * ISPACK FORTRAN SUBROUTINE LIBRARY FOR SCIENTIFIC COMPUTING
-* Copyright (C) 1998--2010 Keiichi Ishioka <ishioka@gfd-dennou.org>
+* Copyright (C) 1998--2013 Keiichi Ishioka <ishioka@gfd-dennou.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
@@ -160,7 +160,7 @@
       CALL SGPSET('LFULL',.TRUE.)
       CALL SGLSET('LCORNER',.FALSE.)
 
-      CALL GROPN(1)
+      CALL GROPN(4)
       CALL UZPSET('INNER',-1)
       CALL GLPSET('LMISS',.TRUE.)
       CALL SGPSET('LCNTL',.TRUE.)
@@ -406,7 +406,11 @@
         END DO
       END DO
       DO K=1,KM
-        RENE(K)=ENE(K)
+        IF(ENE(K).NE.0) THEN
+          RENE(K)=ENE(K)
+        ELSE
+          RENE(K)=1E-30
+        END IF
       END DO      
 
       CALL GRFRM
@@ -441,7 +445,11 @@
         END DO
       END DO
       DO K=1,KM
-        RENE(K)=ENE(K)
+        IF(ENE(K).NE.0) THEN
+          RENE(K)=ENE(K)
+        ELSE
+          RENE(K)=1E-30
+        END IF
       END DO
 
       CALL GRFRM
@@ -476,7 +484,11 @@
         END DO
       END DO
       DO K=1,KM
-        RENE(K)=ENE(K)
+        IF(ENE(K).NE.0) THEN
+          RENE(K)=ENE(K)
+        ELSE
+          RENE(K)=1E-30
+        END IF
       END DO
 
       CALL GRFRM
