@@ -1,6 +1,6 @@
 ************************************************************************
 * ISPACK FORTRAN SUBROUTINE LIBRARY FOR SCIENTIFIC COMPUTING
-* Copyright (C) 1998--2011 Keiichi Ishioka <ishioka@gfd-dennou.org>
+* Copyright (C) 1998--2013 Keiichi Ishioka <ishioka@gfd-dennou.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
@@ -75,7 +75,7 @@
       CALL SWLSET('LALT',.TRUE.)
       CALL SGLSET('LCORNER',.FALSE.)
 
-      CALL GROPN(1)
+      CALL GROPN(4)
       CALL UZPSET('INNER',-1)
       CALL SLRAT(1.0,1.0)
       CALL GLPSET('LMISS',.TRUE.)
@@ -133,7 +133,11 @@
 
       CALL P3ESPT(NM,MM,LM,KMAX,Z,ES)
       DO K=1,KMAX
-        RES(K)=ES(K)
+        IF(RES(K).EQ.0) THEN
+          RES(K)=1D-30
+        ELSE
+          RES(K)=ES(K)
+        END IF
         RK(K)=K
       END DO
 
