@@ -1,6 +1,6 @@
 ************************************************************************
 * ISPACK FORTRAN SUBROUTINE LIBRARY FOR SCIENTIFIC COMPUTING
-* Copyright (C) 1998--2010 Keiichi Ishioka <ishioka@gfd-dennou.org>
+* Copyright (C) 1998--2013 Keiichi Ishioka <ishioka@gfd-dennou.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
@@ -31,7 +31,7 @@
       RN(1,2)=1
 
       DO L=2,LM
-        N=SQRT(1D0*(L-1))
+        N=INT(SQRT(1D0*(L-1)))
         RN(L,1)=-N*(N+1)
         RN(L,2)=1D0/RN(L,1)
       END DO
