@@ -1,6 +1,6 @@
 ************************************************************************
 * ISPACK FORTRAN SUBROUTINE LIBRARY FOR SCIENTIFIC COMPUTING
-* Copyright (C) 1998--2011 Keiichi Ishioka <ishioka@gfd-dennou.org>
+* Copyright (C) 1998--2013 Keiichi Ishioka <ishioka@gfd-dennou.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
@@ -32,7 +32,7 @@
       CL(1,4)=1
       CL(1,5)=0
       DO L=2,(MM+1)*(MM+1)
-        N=SQRT(1D0*(L-1))
+        N=INT(SQRT(1D0*(L-1)))
         C=-DNU*((2-ALPHA)*(-N*(N+1))+2)/2
         S=-BARPHI*(-N*(N+1))
         FREQ2=S-C*C
